==> jc-1.4.0.tar.gz: polyglot/lex/Keyword.c <==
// public class polyglot.lex.Keyword

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 2ea531511a81498b polyglot_lex_Keyword
// @dep_class 28b2d50426072b60 polyglot_lex_Token
// @dep_class 32c9a088c5dac046 polyglot_util_Position

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header polyglot_lex_Keyword
// @dep_header polyglot_util_Position

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "polyglot/lex/Keyword.h"
#include "polyglot/util/Position.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.String keyword
static _jc_field _jc_polyglot_lex_Keyword$field_info$keyword = {
	.name=		"keyword",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_polyglot_lex_Keyword$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_polyglot_lex_Keyword$object, refs[-1].polyglot_lex_Keyword.keyword),
};

// Fields
static _jc_field *const _jc_polyglot_lex_Keyword$fields[] = {
	&_jc_polyglot_lex_Keyword$field_info$keyword
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(polyglot.util.Position, java.lang.String, int)
//

static _jc_linenum _jc_polyglot_lex_Keyword$linenum_table$_init$37e74d0be0d3e539[];

static const unsigned char _jc_polyglot_lex_Keyword$param_ptypes$_init$37e74d0be0d3e539[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_INT, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_lex_Keyword$param_types$_init$37e74d0be0d3e539[] = {
	&_jc_polyglot_util_Position$type,
	&_jc_java_lang_String$type,
	&_jc_int$prim$type
};

_jc_method _jc_polyglot_lex_Keyword$method_info$_init$37e74d0be0d3e539 = {
	.name=			"<init>",
	.signature=		"(Lpolyglot/util/Position;Ljava/lang/String;I)V",
	.class=			&_jc_polyglot_lex_Keyword$type,
	.param_types=		&_jc_polyglot_lex_Keyword$param_types$_init$37e74d0be0d3e539,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_lex_Keyword$param_ptypes$_init$37e74d0be0d3e539,
	.signature_hash=	_JC_JLONG(0x37e74d0be0d3e539),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_lex_Keyword$method$_init$37e74d0be0d3e539,
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_polyglot_lex_Keyword$linenum_table$_init$37e74d0be0d3e539
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_lex_Keyword, _init$37e74d0be0d3e539);

void
_jc_polyglot_lex_Keyword$method$_init$37e74d0be0d3e539(_jc_env *const env, _jc_polyglot_lex_Keyword$object *this, _jc_polyglot_util_Position$object *param0, _jc_java_lang_String$object *param1, jint param2)
{
	jint i0;
	struct _jc_polyglot_lex_Keyword$object *r0;
	struct _jc_polyglot_util_Position$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	i0 = param2;
	_JC_REF_FIELD(env, r0, polyglot_lex_Token, position) = r1;
	_JC_PRIM_FIELD(env, r0, polyglot_lex_Token, symbol) = i0;
	_JC_LINE_NUMBER(12);				// 0
	_JC_REF_FIELD(env, r0, polyglot_lex_Keyword, keyword) = r2;
	_JC_LINE_NUMBER(13);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_polyglot_lex_Keyword$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_polyglot_lex_Keyword$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_lex_Keyword$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_polyglot_lex_Keyword$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_polyglot_lex_Keyword$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_lex_Keyword$vtable, polyglot_lex_Keyword.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_lex_Keyword$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_lex_Keyword, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_polyglot_lex_Keyword$object *this)
{
	struct _jc_polyglot_lex_Keyword$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_String$object *r3;
	_jc_char_array *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(16);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r4 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r4;
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "Keyword<"));
	r2 = _JC_REF_FIELD(env, r0, polyglot_lex_Keyword, keyword);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, ">"));
	r3 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r3, r1);
	return r3;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_lex_Keyword$methods[] = {
	&_jc_polyglot_lex_Keyword$method_info$_init$37e74d0be0d3e539,
	&_jc_polyglot_lex_Keyword$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_lex_Keyword$instanceof_hash_bucket_11[] = {
	&_jc_polyglot_lex_Keyword$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_Keyword$instanceof_hash_bucket_96[] = {
	&_jc_polyglot_lex_Token$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_Keyword$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_lex_Keyword$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[11]=	_jc_polyglot_lex_Keyword$instanceof_hash_bucket_11,
	[96]=	_jc_polyglot_lex_Keyword$instanceof_hash_bucket_96,
	[113]=	_jc_polyglot_lex_Keyword$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_lex_Keyword$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "polyglot/lex/Token",	_JC_JLONG(0x28b2d50426072b60) },
	{ "polyglot/util/Position",	_JC_JLONG(0x32c9a088c5dac046) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_lex_Keyword$vtype _jc_polyglot_lex_Keyword$type = {
    .type= {
	.name=			"polyglot/lex/Keyword",
	.superclass=		&_jc_polyglot_lex_Token$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0x2ea531511a81498b),
		.source_file=		"Keyword.java",
		.instance_size=		sizeof(_jc_polyglot_lex_Keyword$refs) + sizeof(_jc_polyglot_lex_Keyword$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_polyglot_lex_Keyword$fields) / sizeof(*_jc_polyglot_lex_Keyword$fields),
		.fields=		_jc_polyglot_lex_Keyword$fields,
		.num_methods=		sizeof(_jc_polyglot_lex_Keyword$methods) / sizeof(*_jc_polyglot_lex_Keyword$methods),
		.methods=		_jc_polyglot_lex_Keyword$methods,
		.instanceof_hash_table=	_jc_polyglot_lex_Keyword$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_lex_Keyword$class_depends) / sizeof(*_jc_polyglot_lex_Keyword$class_depends),
		.class_depends=		_jc_polyglot_lex_Keyword$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_lex_Token= {
	    .getPosition$93950f582a09a82d=
		&_jc_polyglot_lex_Token$method$getPosition$93950f582a09a82d,
	    .symbol$4d0189d5e9737af4=
		&_jc_polyglot_lex_Token$method$symbol$4d0189d5e9737af4,
	},
	.polyglot_lex_Keyword= {
	    .toString$7ea43b33b80a3070=
		&_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: polyglot/lex/Keyword.c <==
// public class polyglot.lex.Keyword

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 2ea531511a81498b polyglot_lex_Keyword
// @dep_class 28b2d50426072b60 polyglot_lex_Token
// @dep_class 32c9a088c5dac046 polyglot_util_Position

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header polyglot_lex_Keyword
// @dep_header polyglot_util_Position

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "polyglot/lex/Keyword.h"
#include "polyglot/util/Position.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.String keyword
static _jc_field _jc_polyglot_lex_Keyword$field_info$keyword = {
	.name=		"keyword",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_polyglot_lex_Keyword$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_polyglot_lex_Keyword$object, refs[-1].polyglot_lex_Keyword.keyword),
};

// Fields
static _jc_field *const _jc_polyglot_lex_Keyword$fields[] = {
	&_jc_polyglot_lex_Keyword$field_info$keyword
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(polyglot.util.Position, java.lang.String, int)
//

static _jc_linenum _jc_polyglot_lex_Keyword$linenum_table$_init$37e74d0be0d3e539[];

static const unsigned char _jc_polyglot_lex_Keyword$param_ptypes$_init$37e74d0be0d3e539[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_INT, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_lex_Keyword$param_types$_init$37e74d0be0d3e539[] = {
	&_jc_polyglot_util_Position$type,
	&_jc_java_lang_String$type,
	&_jc_int$prim$type
};

_jc_method _jc_polyglot_lex_Keyword$method_info$_init$37e74d0be0d3e539 = {
	.name=			"<init>",
	.signature=		"(Lpolyglot/util/Position;Ljava/lang/String;I)V",
	.class=			&_jc_polyglot_lex_Keyword$type,
	.param_types=		&_jc_polyglot_lex_Keyword$param_types$_init$37e74d0be0d3e539,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_lex_Keyword$param_ptypes$_init$37e74d0be0d3e539,
	.signature_hash=	_JC_JLONG(0x37e74d0be0d3e539),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_lex_Keyword$method$_init$37e74d0be0d3e539,
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_polyglot_lex_Keyword$linenum_table$_init$37e74d0be0d3e539
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_lex_Keyword, _init$37e74d0be0d3e539);

void _JC_JCNI_ATTR
_jc_polyglot_lex_Keyword$method$_init$37e74d0be0d3e539(_jc_env *const env, _jc_polyglot_lex_Keyword$object *this, _jc_polyglot_util_Position$object *param0, _jc_java_lang_String$object *param1, jint param2)
{
	jint i0;
	struct _jc_polyglot_lex_Keyword$object *r0;
	struct _jc_polyglot_util_Position$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	i0 = param2;
	_JC_REF_FIELD(env, r0, polyglot_lex_Token, position) = r1;
	_JC_PRIM_FIELD(env, r0, polyglot_lex_Token, symbol) = i0;
	_JC_LINE_NUMBER(12);				// 0
	_JC_REF_FIELD(env, r0, polyglot_lex_Keyword, keyword) = r2;
	_JC_LINE_NUMBER(13);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_polyglot_lex_Keyword$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_polyglot_lex_Keyword$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_lex_Keyword$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_polyglot_lex_Keyword$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_polyglot_lex_Keyword$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_lex_Keyword$vtable, polyglot_lex_Keyword.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_lex_Keyword$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_lex_Keyword, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_polyglot_lex_Keyword$object *this)
{
	struct _jc_polyglot_lex_Keyword$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_String$object *r3;
	_jc_char_array *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(16);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r4 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r4;
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "Keyword<"));
	r2 = _JC_REF_FIELD(env, r0, polyglot_lex_Keyword, keyword);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, ">"));
	r3 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r3, r1);
	return r3;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_lex_Keyword$methods[] = {
	&_jc_polyglot_lex_Keyword$method_info$_init$37e74d0be0d3e539,
	&_jc_polyglot_lex_Keyword$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_lex_Keyword$instanceof_hash_bucket_11[] = {
	&_jc_polyglot_lex_Keyword$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_Keyword$instanceof_hash_bucket_96[] = {
	&_jc_polyglot_lex_Token$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_Keyword$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_lex_Keyword$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[11]=	_jc_polyglot_lex_Keyword$instanceof_hash_bucket_11,
	[96]=	_jc_polyglot_lex_Keyword$instanceof_hash_bucket_96,
	[101]=	_jc_polyglot_lex_Keyword$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_lex_Keyword$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "polyglot/lex/Token",	_JC_JLONG(0x28b2d50426072b60) },
	{ "polyglot/util/Position",	_JC_JLONG(0x32c9a088c5dac046) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_lex_Keyword$vtype _jc_polyglot_lex_Keyword$type = {
    .type= {
	.name=			"polyglot/lex/Keyword",
	.superclass=		&_jc_polyglot_lex_Token$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0x2ea531511a81498b),
		.source_file=		"Keyword.java",
		.instance_size=		sizeof(_jc_polyglot_lex_Keyword$refs) + sizeof(_jc_polyglot_lex_Keyword$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_polyglot_lex_Keyword$fields) / sizeof(*_jc_polyglot_lex_Keyword$fields),
		.fields=		_jc_polyglot_lex_Keyword$fields,
		.num_methods=		sizeof(_jc_polyglot_lex_Keyword$methods) / sizeof(*_jc_polyglot_lex_Keyword$methods),
		.methods=		_jc_polyglot_lex_Keyword$methods,
		.instanceof_hash_table=	_jc_polyglot_lex_Keyword$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_lex_Keyword$class_depends) / sizeof(*_jc_polyglot_lex_Keyword$class_depends),
		.class_depends=		_jc_polyglot_lex_Keyword$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_lex_Token= {
	    .getPosition$93950f582a09a82d=
		&_jc_polyglot_lex_Token$method$getPosition$93950f582a09a82d,
	    .symbol$4d0189d5e9737af4=
		&_jc_polyglot_lex_Token$method$symbol$4d0189d5e9737af4,
	},
	.polyglot_lex_Keyword= {
	    .toString$7ea43b33b80a3070=
		&_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070,
	},
    }
};
